@@ -53,15 +53,22 @@ __osip_nist_init (osip_nist_t ** nist, osip_t * osip, osip_message_t * invite)
 
     i = osip_strncasecmp (proto, "TCP", 3);
     if (i != 0)
-      {				/* for other reliable protocol than TCP, the timer
-				   must be desactived by the external application */
+      {
 	(*nist)->timer_j_length = 64 * DEFAULT_T1;
+#ifdef NEW_TIMER
+	(*nist)->timer_j_start.tv_sec = -1; /* not started */
+#else
 	(*nist)->timer_j_start = -1;	/* not started */
+#endif
       }
     else
       {				/* TCP is used: */
 	(*nist)->timer_j_length = 0;	/* MUST do the transition immediatly */
+#ifdef NEW_TIMER
+	(*nist)->timer_j_start.tv_sec = -1; /* not started */
+#else
 	(*nist)->timer_j_start = -1;	/* not started */
+#endif
       }
   }
 
@@ -86,6 +93,8 @@ __osip_nist_free (osip_nist_t * nist)
 }
 
 
+#ifndef NEW_TIMER
+
 osip_event_t *
 __osip_nist_need_timer_j_event (osip_nist_t * nist, state_t state, int transactionid)
 {
@@ -102,3 +111,25 @@ __osip_nist_need_timer_j_event (osip_nist_t * nist, state_t state, int transacti
     }
   return NULL;
 }
+
+#else
+
+osip_event_t *
+__osip_nist_need_timer_j_event (osip_nist_t * nist, state_t state, int transactionid)
+{
+  struct timeval now;
+  gettimeofday(&now, NULL);
+
+  if (nist == NULL)
+    return NULL;
+  if (state == NIST_COMPLETED)
+    {
+      if (nist->timer_j_start.tv_sec == -1)
+	return NULL;
+      if (timercmp(&now, &nist->timer_j_start, > ))
+	return __osip_event_new (TIMEOUT_J, transactionid);
+    }
+  return NULL;
+}
+
+#endif
